@@ -1,6 +1,6 @@
 from importlib.resources import files
 
-from .core import Filter, Timeline, flatten, intersection, timeline, union
+from .core import Filter, Timeline, flatten, intersection, union
 from .interval import Interval
 from .metrics import (
     count_intervals,
@@ -9,6 +9,7 @@ from .metrics import (
     min_duration,
     total_duration,
 )
+from .mutable.memory import timeline
 from .properties import (
     Property,
     days,
@@ -32,6 +33,7 @@ docs = {
     "readme": (_docs_path / "README.md").read_text(),
     "tutorial": (_docs_path / "TUTORIAL.md").read_text(),
     "api": (_docs_path / "API.md").read_text(),
+    "gcsa": (_docs_path / "GCSA.md").read_text(),
 }
 
 __all__ = [
