@@ -1,7 +1,6 @@
-import bisect
 import heapq
 from abc import ABC, abstractmethod
-from collections.abc import Iterable, Sequence
+from collections.abc import Iterable, Iterator
 from dataclasses import replace
 from datetime import datetime
 from functools import reduce
@@ -31,7 +30,13 @@ class Timeline(ABC, Generic[IvlOut]):
 
     def __getitem__(self, item: slice) -> Iterable[IvlOut]:
         start = self._coerce_bound(item.start, "start")
-        end = self._coerce_bound(item.stop, "end")
+        end_bound = self._coerce_bound(item.stop, "end")
+
+        # Convert exclusive slice bound to inclusive interval bound
+        # Python slicing [start:end] excludes end
+        # Our intervals are now exclusive [start, end)
+        # So we use the end bound directly
+        end = end_bound
 
         # Automatically clip intervals to query bounds via intersection with solid
         # timeline
@@ -192,9 +197,23 @@ class _SolidTimeline(Timeline[Interval]):
 solid: Timeline[Interval] = _SolidTimeline()
 
 
+def _flatten_sources(
+    sources: Iterable[Timeline[IvlOut]],
+    cls: type["Union[IvlOut]"] | type["Intersection[IvlOut]"],
+) -> tuple[Timeline[IvlOut], ...]:
+    """Flatten nested instances of the same class (Union or Intersection)."""
+    flattened: list[Timeline[IvlOut]] = []
+    for source in sources:
+        if isinstance(source, cls):
+            flattened.extend(source.sources)
+        else:
+            flattened.append(source)
+    return tuple(flattened)
+
+
 class Union(Timeline[IvlOut]):
     def __init__(self, *sources: Timeline[IvlOut]):
-        self.sources: tuple[Timeline[IvlOut], ...] = sources
+        self.sources: tuple[Timeline[IvlOut], ...] = _flatten_sources(sources, Union)
 
     @property
     @override
@@ -210,16 +229,70 @@ class Union(Timeline[IvlOut]):
         return merged
 
 
+class _SourceState:
+    """Per-source state for the intersection algorithm.
+
+    Tracks the current interval, exhaustion status, and processing history
+    for a single source in the intersection.
+    """
+
+    def __init__(self, iterator: Iterable[Interval]) -> None:
+        self._iterator: Iterator[Interval] = iter(iterator)
+        self.current: Interval | None = None
+        self.exhausted: bool = False
+        self.last_processed_cutoff: int | None = None
+        # Initialize with first interval
+        self.advance()
+
+    def advance(self) -> bool:
+        """Advance to next interval. Returns True if state changed."""
+        if self.exhausted:
+            return False
+        try:
+            self.current = next(self._iterator)
+            self.last_processed_cutoff = None
+            return True
+        except StopIteration:
+            self.exhausted = True
+            # Keep current interval for continued overlap checks with other sources
+            return True  # State changed (now exhausted)
+
+    def advance_if_ends_at(self, cutoff: int) -> bool:
+        """Advance if current interval ends at cutoff. Returns True if advanced."""
+        if (
+            self.current is not None
+            and self.current.finite_end == cutoff
+            and not self.exhausted
+        ):
+            return self.advance()
+        return False
+
+    def advance_if_stalled(self, cutoff: int) -> bool:
+        """Advance if processed at cutoff but doesn't end there.
+
+        This handles the case where a mask source advanced but this emit source's
+        interval extends past the cutoff. Without this, we'd miss subsequent
+        intervals with identical start/end times.
+        """
+        if (
+            self.current is not None
+            and not self.exhausted
+            and self.last_processed_cutoff == cutoff
+            and self.current.finite_end != cutoff
+        ):
+            return self.advance()
+        return False
+
+    def was_processed_at(self, cutoff: int) -> bool:
+        """Check if already processed at this cutoff (to avoid duplicates)."""
+        return self.last_processed_cutoff == cutoff
+
+
 class Intersection(Timeline[IvlOut]):
     def __init__(self, *sources: Timeline[IvlOut]):
-        flattened: list[Timeline[IvlOut]] = []
-        for source in sources:
-            if isinstance(source, Intersection):
-                flattened.extend(source.sources)
-            else:
-                flattened.append(source)
-
-        self.sources: tuple[Timeline[IvlOut], ...] = tuple(flattened)
+        self.sources: tuple[Timeline[IvlOut], ...] = _flatten_sources(
+            sources, Intersection
+        )
 
     @property
     @override
@@ -231,73 +304,90 @@ class Intersection(Timeline[IvlOut]):
     def fetch(self, start: int | None, end: int | None) -> Iterable[IvlOut]:
         """Compute intersection using a multi-way merge with sliding window.
 
-        Algorithm: Maintains one "current" interval from each source and advances
-        them in lockstep. When all current intervals overlap, yields a trimmed copy
-        from sources (behavior depends on source types).
+        Algorithm:
+        1. Maintain one "current" interval from each source
+        2. Find the overlap region across all current intervals
+        3. Yield trimmed copies from emit sources
+        4. Advance sources whose intervals end at the overlap boundary
+        5. Handle stall condition when emit sources extend past mask boundaries
+        6. Repeat until no more overlaps possible
 
-        Auto-flattening optimization:
-        - All mask sources: Yields one interval per overlap (auto-flattened)
-        - Mixed mask/rich: Yields only from rich sources (preserves metadata)
-        - All rich sources: Yields from all sources (preserves metadata)
+        Emit behavior (based on source types):
+        - All mask sources: Emit one interval per overlap (auto-flattened)
+        - Mixed mask/rich: Emit only from rich sources (preserves metadata)
+        - All rich sources: Emit from all sources
 
-        Key invariant: overlap_start <= overlap_end means all sources have coverage.
+        The algorithm correctly handles multiple intervals with identical times
+        from the same source by detecting and resolving stall conditions.
         """
         if not self.sources:
             return ()
 
-        # Determine behavior based on source types
+        # Determine which sources to emit from based on mask/rich types
         mask_sources = [s._is_mask for s in self.sources]
-        all_mask = all(mask_sources)
-        any_mask = any(mask_sources)
-
-        # Get indices of sources to emit from
-        if all_mask:
-            # All mask: emit just one interval per overlap (auto-flatten)
-            emit_indices = [0]
-        elif any_mask:
-            # Mixed: emit only from rich sources (preserve their metadata)
-            emit_indices = [i for i, is_mask in enumerate(mask_sources) if not is_mask]
+        if all(mask_sources):
+            emit_indices = frozenset([0])  # All mask: emit just one (auto-flatten)
+        elif any(mask_sources):
+            emit_indices = frozenset(
+                i for i, is_mask in enumerate(mask_sources) if not is_mask
+            )
         else:
-            # All rich: emit from all (current behavior)
-            emit_indices = list(range(len(self.sources)))
+            emit_indices = frozenset(range(len(self.sources)))
 
-        iterators = [iter(source.fetch(start, end)) for source in self.sources]
+        # Initialize per-source state
+        states = [_SourceState(source.fetch(start, end)) for source in self.sources]
 
         def generate() -> Iterable[IvlOut]:
-            # Initialize: get first interval from each source
-            try:
-                current = [next(iterator) for iterator in iterators]
-            except StopIteration:
+            # Early exit if all sources exhausted on init (no intervals)
+            if all(s.exhausted and s.current is None for s in states):
+                return
+
+            # Special case: single source intersection is identity
+            if len(states) == 1:
+                state = states[0]
+                while state.current is not None:
+                    yield state.current
+                    state.advance()
+                    if state.exhausted:
+                        break  # Don't re-yield the last interval
                 return
 
             while True:
-                # Find overlap region across all current intervals
-                # Use finite properties to handle None (unbounded) values
-                overlap_start = max(event.finite_start for event in current)
-                overlap_end = min(event.finite_end for event in current)
+                # Check if all sources have a current interval
+                active = [s.current for s in states if s.current is not None]
+                if len(active) < len(states):
+                    return  # Need intervals from ALL sources for intersection
 
-                # If there's actual overlap, yield trimmed copy from selected sources
-                if overlap_start <= overlap_end:
+                # Find overlap region across all current intervals
+                overlap_start = max(ivl.finite_start for ivl in active)
+                overlap_end = min(ivl.finite_end for ivl in active)
+
+                # Emit trimmed intervals from emit sources
+                if overlap_start < overlap_end:
                     for idx in emit_indices:
+                        state = states[idx]
+                        if state.current is None or state.was_processed_at(overlap_end):
+                            continue
                         # Convert sentinel values back to None for unbounded intervals
                         start_val = overlap_start if overlap_start != NEG_INF else None
                         end_val = overlap_end if overlap_end != POS_INF else None
-                        yield replace(current[idx], start=start_val, end=end_val)
+                        yield replace(state.current, start=start_val, end=end_val)
+                        state.last_processed_cutoff = overlap_end
 
-                # Advance any interval that ends at the overlap boundary
+                # Advance sources whose intervals end at the overlap boundary
                 cutoff = overlap_end
-                advanced = False
-                for idx, event in enumerate(current):
-                    if event.finite_end == cutoff:
-                        try:
-                            current[idx] = next(iterators[idx])
-                            advanced = True
-                        except StopIteration:
-                            return
+                advanced = any(s.advance_if_ends_at(cutoff) for s in states)
 
-                # If no interval advanced, we've exhausted all overlaps
+                # Handle stall condition: emit sources processed but extending past
+                # cutoff. This ensures we get all intervals with identical times
+                # from same source
                 if not advanced:
-                    return
+                    advanced = any(
+                        states[idx].advance_if_stalled(cutoff) for idx in emit_indices
+                    )
+
+                if not advanced:
+                    return  # No progress possible, done
 
         return generate()
 
@@ -395,20 +485,18 @@ class Difference(Timeline[IvlOut]):
                     overlap_start = max(cursor, current_subtractor.finite_start)
                     overlap_end = min(event_end, current_subtractor.finite_end)
 
-                    if overlap_start <= overlap_end:
+                    if overlap_start < overlap_end:
                         # Emit fragment before the hole (if any)
-                        if cursor <= overlap_start - 1:
+                        if cursor < overlap_start:
                             # Convert back to None if sentinel value
                             start_val = cursor if cursor != NEG_INF else None
                             end_val = (
-                                overlap_start - 1
-                                if overlap_start - 1 != NEG_INF
-                                else None
+                                overlap_start if overlap_start != NEG_INF else None
                             )
                             yield replace(event, start=start_val, end=end_val)
                         # Move cursor past the hole
-                        cursor = overlap_end + 1
-                        if cursor > event_end:
+                        cursor = overlap_end
+                        if cursor >= event_end:
                             break
 
                     # Advance if subtractor ends within this event
@@ -418,7 +506,7 @@ class Difference(Timeline[IvlOut]):
                         break
 
                 # Emit final fragment after all holes (if any remains)
-                if cursor <= event_end:
+                if cursor < event_end:
                     # Convert back to None if sentinel value
                     start_val = cursor if cursor != NEG_INF else None
                     end_val = event_end if event_end != POS_INF else None
@@ -469,24 +557,22 @@ class Complement(Timeline[Interval]):
                 segment_start = max(event_start, start_bound)
                 segment_end = min(event_end, end_bound)
 
-                if segment_end < cursor:
+                if segment_end <= cursor:
                     continue
 
                 if segment_start > cursor:
                     # Emit gap before this event
                     # Convert sentinels back to None for unbounded gaps
                     gap_start = cursor if cursor != NEG_INF else None
-                    gap_end = (
-                        segment_start - 1 if segment_start - 1 != NEG_INF else None
-                    )
+                    gap_end = segment_start if segment_start != NEG_INF else None
                     yield Interval(start=gap_start, end=gap_end)
 
-                cursor = max(cursor, segment_end + 1)
+                cursor = max(cursor, segment_end)
 
                 if cursor > end_bound:
                     return
 
-            if cursor <= end_bound:
+            if cursor < end_bound:
                 # Emit final gap
                 # Convert sentinels back to None for unbounded gaps
                 gap_start = cursor if cursor != NEG_INF else None
@@ -496,93 +582,6 @@ class Complement(Timeline[Interval]):
         return generate()
 
 
-class _StaticTimeline(Timeline[IvlOut], Generic[IvlOut]):
-    """Timeline backed by a static collection of intervals.
-
-    This is useful for creating timelines from a fixed set of intervals
-    without needing to subclass Timeline.
-    """
-
-    def __init__(self, intervals: Sequence[IvlOut]):
-        # Use finite properties for sorting to handle None (unbounded) values
-        self._intervals: tuple[IvlOut, ...] = tuple(
-            sorted(intervals, key=lambda e: (e.finite_start, e.finite_end))
-        )
-
-        # Build max-end prefix array for efficient query pruning
-        # max_end_prefix[i] = max(interval.finite_end for interval in intervals[:i+1])
-        self._max_end_prefix: list[int] = []
-        max_so_far = float("-inf")
-        for interval in self._intervals:
-            max_so_far = max(max_so_far, interval.finite_end)
-            self._max_end_prefix.append(int(max_so_far))
-
-    @override
-    def fetch(self, start: int | None, end: int | None) -> Iterable[IvlOut]:
-        # Use binary search to narrow the range of intervals to check
-        # Intervals are sorted by (finite_start, finite_end)
-
-        if not self._intervals:
-            return
-
-        start_idx = 0
-        end_idx = len(self._intervals)
-
-        # Use max-end prefix to skip intervals that definitely can't overlap
-        # Find first position where max_end >= start (all before can be skipped)
-        if start is not None:
-            start_idx = bisect.bisect_left(self._max_end_prefix, start)
-
-        # Use binary search on starts to find where to stop iterating
-        # Find first interval with finite_start > end
-        if end is not None:
-            end_idx = bisect.bisect_right(
-                self._intervals, end, key=lambda interval: interval.finite_start
-            )
-
-        # Iterate only through the narrowed range
-        for interval in self._intervals[start_idx:end_idx]:
-            # Final filter: skip intervals that end before our start bound
-            if start is not None and interval.finite_end < start:
-                continue
-            yield interval
-
-
-def timeline(*intervals: IvlOut) -> Timeline[IvlOut]:
-    """Create a timeline from a collection of intervals.
-
-    This is a convenience function for creating timelines without needing to
-    subclass Timeline. The returned timeline is immutable and sorts intervals
-    by (start, end).
-
-    Args:
-        *intervals: Variable number of interval objects
-
-    Returns:
-        Timeline that yields the provided intervals
-
-    Example:
-        >>> from calgebra import timeline, Interval
-        >>>
-        >>> # Create a simple timeline
-        >>> my_timeline = timeline(
-        ...     Interval(start=1000, end=2000),
-        ...     Interval(start=5000, end=6000),
-        ... )
-        >>>
-        >>> # Works with subclassed intervals too
-        >>> @dataclass(frozen=True, kw_only=True)
-        ... class Event(Interval):
-        ...     title: str
-        >>>
-        >>> events = timeline(
-        ...     Event(start=1000, end=2000, title="Meeting"),
-        ...     Event(start=5000, end=6000, title="Lunch"),
-        ... )
-    """
-    return _StaticTimeline(intervals)
-
-
 def flatten(timeline: "Timeline[Any]") -> "Timeline[Interval]":
     """Return a timeline that yields coalesced intervals for the given source.
 
