@@ -55,7 +55,7 @@ def test_recurring_weekly_with_time_window():
 
     # Check duration is 30 minutes
     assert standup[0].start is not None and standup[0].end is not None
-    duration = standup[0].end - standup[0].start + 1
+    duration = standup[0].end - standup[0].start
     assert duration == 1800  # 30 minutes in seconds
 
 
@@ -63,15 +63,19 @@ def test_recurring_biweekly():
     """Test bi-weekly (every other week) pattern."""
     # 4 weeks
     start = int(datetime(2025, 1, 6, 0, 0, 0, tzinfo=timezone.utc).timestamp())
-    end = int(datetime(2025, 2, 3, 0, 0, 0, tzinfo=timezone.utc).timestamp())
+    end = int(datetime(2025, 2, 4, 0, 0, 0, tzinfo=timezone.utc).timestamp())
 
     # Every other Monday
     biweekly = list(
         recurring(freq="weekly", interval=2, day="monday", tz="UTC")[start:end]
     )
 
-    # Should get 3 Mondays (Jan 6, Jan 20, Feb 3) - rrule includes start date
-    assert len(biweekly) == 3
+    # Should get 2 Mondays (Jan 13, Jan 27)
+    # Jan 6 is skipped because it is an "Odd" week relative to the Monday Epoch (1969-12-29)
+    # Epoch-aligned phase ensures consistent results regardless of query start.
+    assert len(biweekly) == 2
+    assert biweekly[0].start == int(datetime(2025, 1, 13, 0, 0, 0, tzinfo=timezone.utc).timestamp())
+    assert biweekly[1].start == int(datetime(2025, 1, 27, 0, 0, 0, tzinfo=timezone.utc).timestamp())
 
 
 def test_recurring_monthly_first_weekday():
@@ -292,7 +296,7 @@ def test_recurring_yearly_with_time_window():
 
     # Check duration is 3 hours
     assert anniversary[0].start is not None and anniversary[0].end is not None
-    duration = anniversary[0].end - anniversary[0].start + 1
+    duration = anniversary[0].end - anniversary[0].start
     assert duration == 10800  # 3 hours in seconds
 
 
@@ -420,7 +424,7 @@ def test_recurring_weekly_with_multi_day_duration():
     # First 4 events should be 3 days long
     for interval in results[:4]:
         assert interval.start is not None and interval.end is not None
-        duration = interval.end - interval.start + 1
+        duration = interval.end - interval.start
         assert duration == 3 * 86400, f"Expected 3 days, got {duration/86400:.2f} days"
 
     # Last event (Jan 31) extends beyond query range and gets clamped
@@ -432,14 +436,14 @@ def test_recurring_weekly_with_multi_day_duration():
 def test_recurring_flatten_merges_overlapping_durations():
     """Test that overlapping recurring events are already flattened by recurring()."""
     from calgebra import DAY, recurring
-    from calgebra.recurrence import _RawRecurringTimeline
+    from calgebra.recurrence import RecurringPattern
 
     query_start = int(datetime(2025, 1, 1, 0, 0, 0, tzinfo=timezone.utc).timestamp())
     query_end = int(datetime(2025, 1, 10, 0, 0, 0, tzinfo=timezone.utc).timestamp())
 
     # Daily events with 2-day duration: creates continuous coverage
     # recurring() already applies flatten(), so check raw timeline first
-    raw = _RawRecurringTimeline(freq="daily", duration=2 * DAY, tz="UTC")
+    raw = RecurringPattern(freq="daily", duration=2 * DAY, tz="UTC")
     raw_results = list(raw.fetch(query_start, query_end))
 
     # Raw should have many overlapping intervals (one per day)
@@ -494,10 +498,10 @@ def test_recurring_raw_lookback_captures_all_overlaps():
     This directly tests the _generate_page lookback logic.
     """
     from calgebra import DAY
-    from calgebra.recurrence import _RawRecurringTimeline
+    from calgebra.recurrence import RecurringPattern
 
     # Create raw timeline (bypasses the flatten in recurring())
-    raw = _RawRecurringTimeline(
+    raw = RecurringPattern(
         freq="daily", duration=4 * DAY, tz="UTC"  # 4-day duration on daily events
     )
 
@@ -528,3 +532,182 @@ def test_recurring_raw_lookback_captures_all_overlaps():
 
     # Should have at least 9 events (Jan 7-15)
     assert len(results) >= 9
+
+
+# Tests for RRULE string conversion
+def test_rrule_string_daily():
+    """Test RRULE conversion for daily patterns."""
+    from calgebra.recurrence import RecurringPattern
+
+    pattern = RecurringPattern(freq="daily")
+    assert pattern.to_rrule_string() == "FREQ=DAILY"
+
+
+def test_rrule_string_weekly_single_day():
+    """Test RRULE conversion for weekly pattern with single day."""
+    from calgebra.recurrence import RecurringPattern
+
+    pattern = RecurringPattern(freq="weekly", day="monday")
+    assert pattern.to_rrule_string() == "FREQ=WEEKLY;BYDAY=MO"
+
+
+def test_rrule_string_weekly_multiple_days():
+    """Test RRULE conversion for weekly pattern with multiple days."""
+    from calgebra.recurrence import RecurringPattern
+
+    pattern = RecurringPattern(freq="weekly", day=["monday", "wednesday", "friday"])
+    rrule_str = pattern.to_rrule_string()
+    # Order may vary, so check components
+    assert rrule_str.startswith("FREQ=WEEKLY;BYDAY=")
+    assert "MO" in rrule_str
+    assert "WE" in rrule_str
+    assert "FR" in rrule_str
+
+
+def test_rrule_string_weekly_with_interval():
+    """Test RRULE conversion for bi-weekly pattern."""
+    from calgebra.recurrence import RecurringPattern
+
+    pattern = RecurringPattern(freq="weekly", day="tuesday", interval=2)
+    assert pattern.to_rrule_string() == "FREQ=WEEKLY;INTERVAL=2;BYDAY=TU"
+
+
+def test_rrule_string_monthly_first_monday():
+    """Test RRULE conversion for first Monday of month."""
+    from calgebra.recurrence import RecurringPattern
+
+    pattern = RecurringPattern(freq="monthly", week=1, day="monday")
+    assert pattern.to_rrule_string() == "FREQ=MONTHLY;BYDAY=1MO"
+
+
+def test_rrule_string_monthly_last_friday():
+    """Test RRULE conversion for last Friday of month."""
+    from calgebra.recurrence import RecurringPattern
+
+    pattern = RecurringPattern(freq="monthly", week=-1, day="friday")
+    assert pattern.to_rrule_string() == "FREQ=MONTHLY;BYDAY=-1FR"
+
+
+def test_rrule_string_monthly_second_wednesday():
+    """Test RRULE conversion for second Wednesday of month."""
+    from calgebra.recurrence import RecurringPattern
+
+    pattern = RecurringPattern(freq="monthly", week=2, day="wednesday")
+    assert pattern.to_rrule_string() == "FREQ=MONTHLY;BYDAY=2WE"
+
+
+def test_rrule_string_monthly_by_day_of_month():
+    """Test RRULE conversion for monthly pattern by day of month."""
+    from calgebra.recurrence import RecurringPattern
+
+    pattern = RecurringPattern(freq="monthly", day_of_month=1)
+    assert pattern.to_rrule_string() == "FREQ=MONTHLY;BYMONTHDAY=1"
+
+
+def test_rrule_string_monthly_multiple_days_of_month():
+    """Test RRULE conversion for monthly pattern with multiple days."""
+    from calgebra.recurrence import RecurringPattern
+
+    pattern = RecurringPattern(freq="monthly", day_of_month=[1, 15])
+    rrule_str = pattern.to_rrule_string()
+    assert rrule_str.startswith("FREQ=MONTHLY;BYMONTHDAY=")
+    assert "1" in rrule_str
+    assert "15" in rrule_str
+
+
+def test_rrule_string_monthly_last_day():
+    """Test RRULE conversion for last day of month."""
+    from calgebra.recurrence import RecurringPattern
+
+    pattern = RecurringPattern(freq="monthly", day_of_month=-1)
+    assert pattern.to_rrule_string() == "FREQ=MONTHLY;BYMONTHDAY=-1"
+
+
+def test_rrule_string_yearly_by_month():
+    """Test RRULE conversion for yearly pattern by month."""
+    from calgebra.recurrence import RecurringPattern
+
+    pattern = RecurringPattern(freq="yearly", month=6)
+    assert pattern.to_rrule_string() == "FREQ=YEARLY;BYMONTH=6"
+
+
+def test_rrule_string_yearly_multiple_months():
+    """Test RRULE conversion for yearly pattern with multiple months."""
+    from calgebra.recurrence import RecurringPattern
+
+    pattern = RecurringPattern(freq="yearly", month=[1, 4, 7, 10])
+    rrule_str = pattern.to_rrule_string()
+    assert rrule_str.startswith("FREQ=YEARLY;BYMONTH=")
+    assert "1" in rrule_str
+    assert "4" in rrule_str
+    assert "7" in rrule_str
+    assert "10" in rrule_str
+
+
+def test_rrule_string_yearly_with_day_of_month():
+    """Test RRULE conversion for yearly pattern with day of month."""
+    from calgebra.recurrence import RecurringPattern
+
+    pattern = RecurringPattern(freq="yearly", month=4, day_of_month=15)
+    rrule_str = pattern.to_rrule_string()
+    assert "FREQ=YEARLY" in rrule_str
+    assert "BYMONTH=4" in rrule_str
+    assert "BYMONTHDAY=15" in rrule_str
+
+
+def test_rrule_string_complex_pattern():
+    """Test RRULE conversion for complex pattern (first Monday of quarter)."""
+    from calgebra.recurrence import RecurringPattern
+
+    # Every 3 months (quarterly), first Monday
+    pattern = RecurringPattern(freq="monthly", interval=3, week=1, day="monday")
+    rrule_str = pattern.to_rrule_string()
+    assert "FREQ=MONTHLY" in rrule_str
+    assert "INTERVAL=3" in rrule_str
+    assert "BYDAY=1MO" in rrule_str
+
+
+def test_rrule_string_direct_helper():
+    """Test rrule_kwargs_to_rrule_string helper function directly."""
+    from calgebra.recurrence import rrule_kwargs_to_rrule_string
+    from dateutil.rrule import WEEKLY, MONTHLY, MO, FR
+
+    # Test with dateutil constants directly
+    kwargs = {"freq": WEEKLY, "byweekday": [MO], "interval": 2}
+    assert rrule_kwargs_to_rrule_string(kwargs) == "FREQ=WEEKLY;INTERVAL=2;BYDAY=MO"
+
+    kwargs = {"freq": MONTHLY, "byweekday": [MO(1)]}
+    assert rrule_kwargs_to_rrule_string(kwargs) == "FREQ=MONTHLY;BYDAY=1MO"
+
+    kwargs = {"freq": MONTHLY, "byweekday": [FR(-1)]}
+    assert rrule_kwargs_to_rrule_string(kwargs) == "FREQ=MONTHLY;BYDAY=-1FR"
+
+
+def test_rrule_string_all_weekdays():
+    """Test RRULE conversion for all weekdays."""
+    from calgebra.recurrence import RecurringPattern
+
+    pattern = RecurringPattern(
+        freq="weekly",
+        day=["monday", "tuesday", "wednesday", "thursday", "friday", "saturday", "sunday"],
+    )
+    rrule_str = pattern.to_rrule_string()
+    assert rrule_str.startswith("FREQ=WEEKLY;BYDAY=")
+    for day in ["MO", "TU", "WE", "TH", "FR", "SA", "SU"]:
+        assert day in rrule_str
+
+
+def test_rrule_string_error_missing_freq():
+    """Test that missing freq raises error."""
+    from calgebra.recurrence import rrule_kwargs_to_rrule_string
+
+    with pytest.raises(ValueError, match="must include 'freq'"):
+        rrule_kwargs_to_rrule_string({})
+
+
+def test_rrule_string_error_unsupported_freq():
+    """Test that unsupported freq raises error."""
+    from calgebra.recurrence import rrule_kwargs_to_rrule_string
+
+    with pytest.raises(ValueError, match="Unsupported frequency"):
+        rrule_kwargs_to_rrule_string({"freq": 999})
